<?php
namespace Teknisa\TCO\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\GER\Services\CrudService;
use Doctrine\DBAL\Connection;
use Exception;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Tco00900ParametrosComerciaisService extends \Teknisa\GER\Controllers\TeknisaCrud{
    
    protected $connection;
    protected $environment;
    protected $crudservice;
    protected $parameterbag;
    
    public function __construct($crudservice, $parameterbag, $entityManager, $environment){
        $this->crudservice   = $crudservice;
        $this->parameterbag  = $parameterbag;
        $this->entityManager = $entityManager;
        $this->connection    = $entityManager->getConnection();
        $this->environment   = $environment;
        
        parent::__construct($crudservice, $parameterbag);
    }
    
    public function verifyExistParamTco($dataSet){
        $sql = "SELECT * FROM PARAMTCO";
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute();
        $result = $query->fetchAll();
        if(empty($result)){
            $this->insertParamTco($dataSet);    
        }
        return $dataSet;
    }
    
    public function retornParamtco($row){
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT 1 
                  FROM PARAMTCO 
                 WHERE NRORG = :NRORG";
                  
        $params = array(
            "NRORG" => property_exists($row, "NRORG") ? $row["NRORG"]: $this->environment->getNrOrg(),
        );
        $query = $connection->prepare($sql);
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function insertParamTco($dataSet){
        $dataSet = $dataSet->getRows();
        $currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
        $sql = "INSERT INTO PARAMTCO (NRPARAMTCO, IDREVRECPADQREGIAO, NRORG, IDATIVO, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, CDFORNECED, CDMARCA, IDHABEMAILPROPOSTA) VALUES (1, :IDREVRECPADQREGIAO, :NRORG, 'S', :DTINCLUSAO, :DTULTATU, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU, :CDFORNECED, :CDMARCA, :IDHABEMAILPROPOSTA)";
        $params = array(
            "IDREVRECPADQREGIAO" => empty($dataSet[0]["IDREVRECPADQREGIAO"]) ? 'N' : $dataSet[0]["IDREVRECPADQREGIAO"],
            "NRORG"              => $this->environment->getNrOrg(),
            "DTINCLUSAO"         => $currentTime,
            "DTULTATU"           => $currentTime,
            "NRORGINCLUSAO"      => $this->environment->getNrOrg(),
            "CDOPERINCLUSAO"     => $this->environment->getCdOperador(),
            "NRORGULTATU"        => $this->environment->getNrOrg(),
            "CDOPERULTATU"       => $this->environment->getCdOperador(),
            "CDFORNECED"         => empty($dataSet[0]["CDFORNECED"]) ? null : $dataSet[0]["CDFORNECED"],
            "CDMARCA"            => empty($dataSet[0]["CDMARCA"]) ? null : $dataSet[0]["CDMARCA"],
            "IDHABEMAILPROPOSTA" => empty($dataSet[0]["IDHABEMAILPROPOSTA"]) ? 'N' : $dataSet[0]["IDHABEMAILPROPOSTA"]
        );
        
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
    }
    
    public function verifyFilialHasChanged($cdfilial){
        $sql = "SELECT CDFILIAL FROM PARAMTCO";
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute();
        $result = $query->fetchAll();
        if($result[0]["CDFILIAL"] == $cdfilial){
            return false;    
        }else{
            return true;
        }
    }
    
    public function updateServicoProposta(){
        $currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
        $sql = "UPDATE SERVICOPROPOSTA SET CDFILIAL = '', CDSERVFILI = '', DTULTATU = :DTULTATU, NRORGULTATU = :NRORGULTATU, CDOPERULTATU = :CDOPERULTATU";
        $params = array(
            "DTULTATU" => $currentTime,
            "NRORGULTATU" => $this->environment->getNrOrg(),
            "CDOPERULTATU" => $this->environment->getCdOperador()
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
    }
    
    public function checkIntervalIsValid($dataSet){
        $sql = "SELECT NRSERCOMPREFEICAO FROM SERCOMPREFEICAO WHERE ((NRSERCOMPREFEICAO <> :NRSERCOMPREFEICAO) OR (:NRSERCOMPREFEICAO IS NULL)) AND ((QTINICIAL BETWEEN :DE AND :ATE) OR (QTFINAL BETWEEN :DE AND :ATE) OR (:DE BETWEEN QTINICIAL AND QTFINAL) OR (:ATE BETWEEN QTINICIAL AND QTFINAL))";
        $params = array(
            "NRSERCOMPREFEICAO" => empty($dataSet["NRSERCOMPREFEICAO"]) ? null : $dataSet["NRSERCOMPREFEICAO"],
            "DE" => $dataSet["QTINICIAL"],
            "ATE" => $dataSet["QTFINAL"]
        );
	    $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        return $result;
    }
}